pub struct WasmBuilderSelectProject { /* private fields */ }Expand description
First step of the WasmBuilder to select the project to build.
Implementations
Sourceimpl WasmBuilderSelectProject
impl WasmBuilderSelectProject
Sourcepub fn with_current_project(self) -> WasmBuilder
pub fn with_current_project(self) -> WasmBuilder
Use the current project as project for building the WASM binary.
Panics
Panics if the CARGO_MANIFEST_DIR variable is not set. This variable
is always set by Cargo in build.rs files.
Sourcepub fn with_project(
self,
path: impl Into<PathBuf>,
) -> Result<WasmBuilder, &'static str>
pub fn with_project( self, path: impl Into<PathBuf>, ) -> Result<WasmBuilder, &'static str>
Use the given path as project for building the WASM binary.
Returns an error if the given path does not points to a Cargo.toml.